@@ -99,6 +99,7 @@ EVENT_TREE = {
     ['object:property-change:accessible-parent', 
     'object:property-change:accessible-name',
     'object:property-change:accessible-description',
+    'object:property-change:accessible-help-text',
     'object:property-change:accessible-value',
     'object:property-change:accessible-role',
     'object:property-change:accessible-table-caption',
@@ -111,7 +112,50 @@ EVENT_TREE = {
     ['object:children-changed:add',
     'object:children-changed:remove'],
   'object:state-changed' :
-    ['object:state-changed:'],
+    ['object:state-changed:active',
+    'object:state-changed:animated',
+    'object:state-changed:armed',
+    'object:state-changed:busy',
+    'object:state-changed:checkable',
+    'object:state-changed:checked',
+    'object:state-changed:collapsed',
+    'object:state-changed:default',
+    'object:state-changed:defunct',
+    'object:state-changed:editable',
+    'object:state-changed:enabled',
+    'object:state-changed:expandable',
+    'object:state-changed:expanded',
+    'object:state-changed:focusable',
+    'object:state-changed:focused',
+    'object:state-changed:has-popup',
+    'object:state-changed:has-tooltip',
+    'object:state-changed:horizontal',
+    'object:state-changed:iconified',
+    'object:state-changed:indeterminate',
+    'object:state-changed:invalid',
+    'object:state-changed:invalid-entry',
+    'object:state-changed:manages-descendants',
+    'object:state-changed:modal',
+    'object:state-changed:multi-line',
+    'object:state-changed:multiselectable',
+    'object:state-changed:opaque',
+    'object:state-changed:pressed',
+    'object:state-changed:read-only',
+    'object:state-changed:resizable',
+    'object:state-changed:required',
+    'object:state-changed:selectable',
+    'object:state-changed:selected',
+    'object:state-changed:sensitive',
+    'object:state-changed:showing',
+    'object:state-changed:selectable-text',
+    'object:state-changed:single-line',
+    'object:state-changed:stale',
+    'object:state-changed:supports-autocompletion',
+    'object:state-changed:transient',
+    'object:state-changed:truncated',
+    'object:state-changed:vertical',
+    'object:state-changed:visible',
+    'object:state-changed:visited'],
   'mouse' :
     ['mouse:abs',
     'mouse:rel',
